==> apache-iotdb-0.12.3-source-release.zip: apache-iotdb-0.12.3/docs/Community/Materials.md <==
<!--

    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

-->

Tips: All English Slides and videos are on slideshare.net and Youtube; 
All Chinese Slides and videos are on myslide.cn and bilibili.
(所有的中文材料都在 myslide.cn 和 bilibili上.)

## Meetups and Talks

* 2021.01.24, BDTC Big Data Technology Conference 2020. 2020中国大数据技术大会. Beijing, China.
* 2020.12.30, The 10th China Cloud Computing Standards and Application Conference. Beijing, China.
  * (Chinese 中文) [Apache IoTDB: Industrial Internet of Things Time Series Data Management System](#bdtc2020). Apache IoTDB: 工业物联网时序数据管理系统. Reporter: Jialin Qiao.
  
* 2020.11.29, Apache IoTDB Meetup, Beijing, China
  * (Chinese 中文) [IoTDB Advanced use and introduction to the principle behind](#meetup2020-1). IoTDB 使用进阶与背后原理介绍. Reporter: Kaifeng Xue.
  * (Chinese 中文) [Mass Time series processing: Distributed meta management in IoTDB](#meetup2020-2). 海量序列处理: IoTDB 的分布式元数据管理技术. Reporter: Chao Wang.
  * (Chinese 中文) [Talkweb Internet of Things Platform and Apache IoTDB  Application Practice Analysis](#meetup2020-3). 拓维物联网平台与 Apache IoTDB 的应用实践分析. Reporter: Bin Huang.
  * (Chinese 中文) [X-DB: an IoTDB based real-time database](#meetup2020-4). 基于IoTDB的X-DB实时数据库的使用情况. Reporter: Wanhong Li.
  * (Chinese 中文) [Apache IoTDB Community Development Profile](#meetup2020-6). Apache IoTDB 社区发展情况简介. Reporter: Xiangdong Huang.
  * (Chinese 中文) [Apache Local community ALC Beijing Introduction](#meetup2020-7). Apache 本土社区 ALC Beijing 介绍. Reporter: Ning Jiang.
  * (Chinese 中文) [Empathy: Needed ability for embracing the open source of collaboration in competition](#meetup2020-8). 同理心: 拥抱竞争中合作的开源必备之技. Reporter: Jiansheng Li.
  * (English) [IoTDB for Digital Twin Platform in Germany](#meetup2020-5). Reporter: Julian Feinaeur.

* 2020.11.14, Open Source Software Supply Chain Summit 2020. "开源软件供应链 2020 峰会"。
  * (Chinese 中文) [Apache IoTDB core technology](#osssummit2020). Apache IoTDB 核心技术剖析. Reporter: Jincheng Sun.

* 2020.10.25, COSCon’ 20 & Apache Roadshow (2020 中国开源年会暨阿帕奇中国路演), Beijing, China.
  * (Chinese 中文) [Apache IoTDB: From Chinese University to the World](#meetup2020-coscon1) Apache IoTDB: 从中国高校走向世界. Reporter: Jialin Qiao.
  * (Chinese 中文) [Apache IoTDB: Managing Industrial IoT Data](#meetup2020-coscon2) Apache IoTDB: 工业物联网数据管理. Reporter: Xiangdong Huang.

* 2020.09.30, ApacheCon 2020, online
  * (English) [Use Cases and Optimizations of IoTDB](#apachecon2020). Reporter: Jialin Qiao

* 2020.09.26, Apache Hadoop Meetup. Shanghai, China. 
  * (Chinese 中文) 从IoTDB到 Hadoop: 工业物联网边云协同开源生态 (略，类似[Apache IoTDB: Managing Industrial IoT Data](#meetup2020-coscon2)). Reporter: Xiangdong Huang.

* 2020.03.02, Building IoT 2020. Essen, Germany.
  * (German) [Industrial IoT mit Open Source](https://www.buildingiot.de/lecture.php?id=10856&source=).  Reporter: Julian Feinauer, Chirstofer Dutz.
  
* 2020.01.12, Apache IoTDB x Apache ShardingSphere Meetup. Beijing, China. 

* 2020.01.04, Apache IoTDB x Apache Pulsar Meetup. Beijing, China. 
  * (Chinese) [Managing Time series data with IoTDB](#meetup2019-pulsar1).  基于IoTDB的时序数据开源解决方案. Reporter: Jialin Qiao.
  * (Chinese) [Apache IoTDB: History and Technical Details](#meetup2019-pulsar2). Apache IoTDB的前世今生与技术细节. Reporter: Xiangdong Huang.

* 2019.12.28, Apache RocketMQ x Apache IoTDB Meetup.  Dalian, China. 
  * (Chinese) [Apache IoTDB: Why We Need a Time Series Database](#meetup2019-dalian). Apache IoTDB：为什么我们需要一个时序数据库. Reporter: Xiangdong Huang.

* 2019.11.09, Apache Event: Embrace Apache Software Foundation. Beijing China.
  * (Chinese) Open Source in Campus - Apache IoTDB as an Example. 从 Apache IoTDB 看高校学生的 Apache 开源实践.  Reporter: Xiangdong Huang.

* 2019.10.23, ApacheCon Europe 2019. Berlin, Germany.
  * (English) [Apache IoTDB: Time Series Database for Industrial IoT](#apeu2019). Reporter: Xiangdong Huang, Julian Feinauer.

* 2019.09.10, ApacheCon North America 2019. Las Vegas, USA.
  * (English) [Hello World! Introducing Apache IoTDB - a Database for the Internet of Things](#apna2019). Reporter: Xiangdong Huang, Julian Feinauer.

* 2019.07.13, Beijing Hackatthon 2019. Beijing, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Xiangdong Huang.

* 2019.05.07, The 2nd Digital China Summit. Fuzhou, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Xiangdong Huang.

* 2019.02.21, Industrial Internet Summit 2019. Beijing, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Jianmin Wang.
                  
* 2018.12.09, Tsinghua Open Source Software Summit 2018. Beijing, China.
  * (Chinese) IoTDB: from Tsinghua IoTDB to Apache IoTDB (incubating). IoTDB:从清华IoTDB到Apache孵化器项目。Reporter: Xiangdong Huang.


## Slides, Audios and Videos

### English

* <span id = "meetup2020-5"> 2020.11, IoTDB for Digital Twin Platform in Germany. Reporter: Julian Feinaeur.</span>

<iframe src="//player.bilibili.com/player.html?aid=928082711&bvid=BV1VT4y1M7ZZ&cid=264981784&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "apachecon2020"> 2020.09, Use Cases and Optimizations of IoTDB. Reporter: Jialin Qiao.</span>

<iframe src="//www.slideshare.net/slideshow/embed_code/key/zwzJmZsMZrnT26" width="640" height="480" frameborder="0" scrolling="no" allowfullscreen> </iframe> 

* 2019.12, Coding example (from Dalian Meetup 2019). Reporter: Xiangdong Huang.

<iframe src="//www.slideshare.net/slideshow/embed_code/key/MZBHJIVnVxff8?startSlide=26" width="640" height="480" frameborder="0" allowfullscreen> </iframe>

* <span id = "apna2019"> 2019.09, ApacheCon North America 2019: Hello World! Introducing Apache IoTDB - a Database for the Internet of Things. Reporter: Xiangdong Huang, Julian Feinauer. </span>

<audio src="https://feathercast.apache.org/wp-content/uploads/2019/09/2019-09-10-hello-world-introducing-apache-iotdb-xiangdong-huang-julian-feinauer.mp3" controls="controls">
</audio>

* <span id = "apeu2019"> 2019.10, ApacheCon Europe 2019: Apache IoTDB: Time Series Database for Industrial IoT. Reporter: Xiangdong Huang, Julian Feinauer. </span>

<iframe src="//www.slideshare.net/slideshow/embed_code/key/lms4cEH1eqnRZC" width="640" height="480" frameborder="0" scrolling="no" allowfullscreen> </iframe>
 
<iframe width="640" height="480" src="https://www.youtube.com/embed/LLFc3yPyTFY" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

### Chinese 中文

* <span id = "bdtc2020"> 2021.01, Apache IoTDB: 工业物联网时序数据管理系统. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76614" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-1"> 2020.11, IoTDB 使用进阶与背后原理介绍. Reporter: Kaifeng Xue. </span>

<iframe src="//player.bilibili.com/player.html?aid=500602330&bvid=BV1fK41137Hi&cid=264969956&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-2"> 2020.11, 海量序列处理: IoTDB 的分布式元数据管理技术. Reporter: Chao Wang. </span>

<iframe src="//player.bilibili.com/player.html?aid=670621766&bvid=BV1xa4y1H7bk&cid=264964955&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-3"> 2020.11, 拓维物联网平台与 Apache IoTDB 的应用实践分析. Reporter: Bin Huang. </span>

<iframe src="//player.bilibili.com/player.html?aid=543103427&bvid=BV1ri4y157ZM&cid=265050086&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-4"> 2020.11, 基于IoTDB的X-DB实时数据库的使用情况. Reporter: Wanhong Li. </span>

<iframe src="//player.bilibili.com/player.html?aid=245547773&bvid=BV1Hv411b7zp&cid=264990446&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-6"> 2020.11, Apache IoTDB 社区发展情况简介. Reporter: Xiangdong Huang. </span>

<iframe src="//player.bilibili.com/player.html?aid=843005071&bvid=BV1z54y1678E&cid=264978842&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-8"> 2020.11, 同理心: 拥抱竞争中合作的开源必备之技. Reporter: Jiansheng Li. </span>

<iframe src="//player.bilibili.com/player.html?aid=970550039&bvid=BV1sp4y1z7vM&cid=264958025&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "osssummit2020"> 2020.11, Apache IoTDB 核心技术剖析. Reporter: Jincheng Sun. </span>

<iframe src="https://myslide.cn/player/76612" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-coscon1"> 2020.10, Apache IoTDB: 从中国高校走向世界. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76613" width="562.5" height="386.75" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-coscon2"> 2020.10, Apache IoTDB: 工业物联网数据管理. Reporter: Xiangdong Huang. </span>

<iframe src="https://myslide.cn/player/76615" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "IoTDBOptimizeAndCaseStudy"> 2020.06, IoTDB 性能优化及案例分享. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76617" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "IoTDBQuickStart"> 2020.05, IoTDB 基本使用. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76619" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "IoTDBOps"> 2020.05, IoTDB 部署运维及常见问题. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76618" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "meetup2019-pulsar1"> 2020.01, 北京Meetup 2019. 基于Apache IoTDB的时序数据开源解决方案. Reporter: Jialin Qiao. </span>

<iframe src="https://myslide.cn/player/76622" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

<iframe src="//player.bilibili.com/player.html?aid=83462398&bvid=BV1sJ411J783&cid=142782989&page=5"   width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2019-pulsar2"> 2020.01, 北京Meetup 2019. Apache IoTDB的前世今生与技术细节. Reporter: Xiangdong Huang. </span>

<iframe src="https://myslide.cn/player/76621" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

<iframe src="//player.bilibili.com/player.html?aid=83462398&bvid=BV1sJ411J783&cid=142782348&page=3"   width="640" height="480"  scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2019-dalian"> 2019.12, 大连Meetup 2019. Apache IoTDB: 工业互联网时序数据库. Reporter: Xiangdong Huang. </span>

<iframe src="https://myslide.cn/player/76620" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* [IoTDB v0.8.0 Query Process Implementation], Reporter: Lei Rui

==> apache-iotdb-0.13.0-source-release.zip: apache-iotdb-0.13.0/docs/Community/Materials.md <==
<!--

    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

-->

Tips: All English Slides and videos are on slideshare.net and Youtube; 
All Chinese Slides and videos are on slidestalk.com and bilibili.
(所有的中文材料都在 slidestalk.com 和 bilibili上.)

## Meetups and Talks

* 2021.01.24, BDTC Big Data Technology Conference 2020. 2020中国大数据技术大会. Beijing, China.
* 2020.12.30, The 10th China Cloud Computing Standards and Application Conference. Beijing, China.
  * (Chinese 中文) [Apache IoTDB: Industrial Internet of Things Time Series Data Management System](#bdtc2020). Apache IoTDB: 工业物联网时序数据管理系统. Reporter: Jialin Qiao.
  
* 2020.11.29, Apache IoTDB Meetup, Beijing, China
  * (Chinese 中文) [IoTDB Advanced use and introduction to the principle behind](#meetup2020-1). IoTDB 使用进阶与背后原理介绍. Reporter: Kaifeng Xue.
  * (Chinese 中文) [Mass Time series processing: Distributed meta management in IoTDB](#meetup2020-2). 海量序列处理: IoTDB 的分布式元数据管理技术. Reporter: Chao Wang.
  * (Chinese 中文) [Talkweb Internet of Things Platform and Apache IoTDB  Application Practice Analysis](#meetup2020-3). 拓维物联网平台与 Apache IoTDB 的应用实践分析. Reporter: Bin Huang.
  * (Chinese 中文) [X-DB: an IoTDB based real-time database](#meetup2020-4). 基于IoTDB的X-DB实时数据库的使用情况. Reporter: Wanhong Li.
  * (Chinese 中文) [Apache IoTDB Community Development Profile](#meetup2020-6). Apache IoTDB 社区发展情况简介. Reporter: Xiangdong Huang.
  * (Chinese 中文) [Apache Local community ALC Beijing Introduction](#meetup2020-7). Apache 本土社区 ALC Beijing 介绍. Reporter: Ning Jiang.
  * (Chinese 中文) [Empathy: Needed ability for embracing the open source of collaboration in competition](#meetup2020-8). 同理心: 拥抱竞争中合作的开源必备之技. Reporter: Jiansheng Li.
  * (English) [IoTDB for Digital Twin Platform in Germany](#meetup2020-5). Reporter: Julian Feinaeur.

* 2020.11.14, Open Source Software Supply Chain Summit 2020. "开源软件供应链 2020 峰会"。
  * (Chinese 中文) [Apache IoTDB core technology](#osssummit2020). Apache IoTDB 核心技术剖析. Reporter: Jincheng Sun.

* 2020.10.25, COSCon’ 20 & Apache Roadshow (2020 中国开源年会暨阿帕奇中国路演), Beijing, China.
  * (Chinese 中文) [Apache IoTDB: From Chinese University to the World](#meetup2020-coscon1) Apache IoTDB: 从中国高校走向世界. Reporter: Jialin Qiao.
  * (Chinese 中文) [Apache IoTDB: Managing Industrial IoT Data](#meetup2020-coscon2) Apache IoTDB: 工业物联网数据管理. Reporter: Xiangdong Huang.

* 2020.09.30, ApacheCon 2020, online
  * (English) [Use Cases and Optimizations of IoTDB](#apachecon2020). Reporter: Jialin Qiao

* 2020.09.26, Apache Hadoop Meetup. Shanghai, China. 
  * (Chinese 中文) 从IoTDB到 Hadoop: 工业物联网边云协同开源生态 (略，类似[Apache IoTDB: Managing Industrial IoT Data](#meetup2020-coscon2)). Reporter: Xiangdong Huang.

* 2020.03.02, Building IoT 2020. Essen, Germany.
  * (German) [Industrial IoT mit Open Source](https://www.buildingiot.de/lecture.php?id=10856&source=).  Reporter: Julian Feinauer, Chirstofer Dutz.
  
* 2020.01.12, Apache IoTDB x Apache ShardingSphere Meetup. Beijing, China. 

* 2020.01.04, Apache IoTDB x Apache Pulsar Meetup. Beijing, China. 
  * (Chinese) [Managing Time series data with IoTDB](#meetup2019-pulsar1).  基于IoTDB的时序数据开源解决方案. Reporter: Jialin Qiao.
  * (Chinese) [Apache IoTDB: History and Technical Details](#meetup2019-pulsar2). Apache IoTDB的前世今生与技术细节. Reporter: Xiangdong Huang.

* 2019.12.28, Apache RocketMQ x Apache IoTDB Meetup.  Dalian, China. 
  * (Chinese) [Apache IoTDB: Why We Need a Time Series Database](#meetup2019-dalian). Apache IoTDB：为什么我们需要一个时序数据库. Reporter: Xiangdong Huang.

* 2019.11.09, Apache Event: Embrace Apache Software Foundation. Beijing China.
  * (Chinese) Open Source in Campus - Apache IoTDB as an Example. 从 Apache IoTDB 看高校学生的 Apache 开源实践.  Reporter: Xiangdong Huang.

* 2019.10.23, ApacheCon Europe 2019. Berlin, Germany.
  * (English) [Apache IoTDB: Time Series Database for Industrial IoT](#apeu2019). Reporter: Xiangdong Huang, Julian Feinauer.

* 2019.09.10, ApacheCon North America 2019. Las Vegas, USA.
  * (English) [Hello World! Introducing Apache IoTDB - a Database for the Internet of Things](#apna2019). Reporter: Xiangdong Huang, Julian Feinauer.

* 2019.07.13, Beijing Hackatthon 2019. Beijing, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Xiangdong Huang.

* 2019.05.07, The 2nd Digital China Summit. Fuzhou, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Xiangdong Huang.

* 2019.02.21, Industrial Internet Summit 2019. Beijing, China.
  * (Chinese) Apache IoTDB (incubating): Time Series Database for IIoT. IoTDB：工业互联网时序数据库. Reporter: Jianmin Wang.
                  
* 2018.12.09, Tsinghua Open Source Software Summit 2018. Beijing, China.
  * (Chinese) IoTDB: from Tsinghua IoTDB to Apache IoTDB (incubating). IoTDB:从清华IoTDB到Apache孵化器项目。Reporter: Xiangdong Huang.


## Slides, Audios and Videos

### English

* <span id = "meetup2020-5"> 2020.11, IoTDB for Digital Twin Platform in Germany. Reporter: Julian Feinaeur.</span>

<iframe src="//player.bilibili.com/player.html?aid=928082711&bvid=BV1VT4y1M7ZZ&cid=264981784&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "apachecon2020"> 2020.09, Use Cases and Optimizations of IoTDB. Reporter: Jialin Qiao.</span>

<iframe src="//www.slideshare.net/slideshow/embed_code/key/zwzJmZsMZrnT26" width="640" height="480" frameborder="0" scrolling="no" allowfullscreen> </iframe> 

* 2019.12, Coding example (from Dalian Meetup 2019). Reporter: Xiangdong Huang.

<iframe src="//www.slideshare.net/slideshow/embed_code/key/MZBHJIVnVxff8?startSlide=26" width="640" height="480" frameborder="0" allowfullscreen> </iframe>

* <span id = "apna2019"> 2019.09, ApacheCon North America 2019: Hello World! Introducing Apache IoTDB - a Database for the Internet of Things. Reporter: Xiangdong Huang, Julian Feinauer. </span>

<audio src="https://feathercast.apache.org/wp-content/uploads/2019/09/2019-09-10-hello-world-introducing-apache-iotdb-xiangdong-huang-julian-feinauer.mp3" controls="controls">
</audio>

* <span id = "apeu2019"> 2019.10, ApacheCon Europe 2019: Apache IoTDB: Time Series Database for Industrial IoT. Reporter: Xiangdong Huang, Julian Feinauer. </span>

<iframe src="//www.slideshare.net/slideshow/embed_code/key/lms4cEH1eqnRZC" width="640" height="480" frameborder="0" scrolling="no" allowfullscreen> </iframe>
 
<iframe width="640" height="480" src="https://www.youtube.com/embed/LLFc3yPyTFY" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

### Chinese 中文

* <span id = "bdtc2020"> 2021.01, Apache IoTDB: 工业物联网时序数据管理系统. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/IoTDB_BDTC2020" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-1"> 2020.11, IoTDB 使用进阶与背后原理介绍. Reporter: Kaifeng Xue. </span>

<iframe src="//player.bilibili.com/player.html?aid=500602330&bvid=BV1fK41137Hi&cid=264969956&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-2"> 2020.11, 海量序列处理: IoTDB 的分布式元数据管理技术. Reporter: Chao Wang. </span>

<iframe src="//player.bilibili.com/player.html?aid=670621766&bvid=BV1xa4y1H7bk&cid=264964955&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-3"> 2020.11, 拓维物联网平台与 Apache IoTDB 的应用实践分析. Reporter: Bin Huang. </span>

<iframe src="//player.bilibili.com/player.html?aid=543103427&bvid=BV1ri4y157ZM&cid=265050086&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-4"> 2020.11, 基于IoTDB的X-DB实时数据库的使用情况. Reporter: Wanhong Li. </span>

<iframe src="//player.bilibili.com/player.html?aid=245547773&bvid=BV1Hv411b7zp&cid=264990446&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-6"> 2020.11, Apache IoTDB 社区发展情况简介. Reporter: Xiangdong Huang. </span>

<iframe src="//player.bilibili.com/player.html?aid=843005071&bvid=BV1z54y1678E&cid=264978842&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2020-8"> 2020.11, 同理心: 拥抱竞争中合作的开源必备之技. Reporter: Jiansheng Li. </span>

<iframe src="//player.bilibili.com/player.html?aid=970550039&bvid=BV1sp4y1z7vM&cid=264958025&page=1" width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "osssummit2020"> 2020.11, Apache IoTDB 核心技术剖析. Reporter: Jincheng Sun. </span>

<iframe src="https://www.slidestalk.com/IoTDB/202011ApacheIoTDBReporter82991" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-coscon1"> 2020.10, Apache IoTDB: 从中国高校走向世界. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/202010ApacheIoTDBReporterJialinQiao42231" width="562.5" height="386.75" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "meetup2020-coscon2"> 2020.10, Apache IoTDB: 工业物联网数据管理. Reporter: Xiangdong Huang. </span>

<iframe src="https://www.slidestalk.com/IoTDB/202010ApacheIoTDBReporterXiangdongHuang11117" width="562.5" height="386" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

* <span id = "IoTDBOptimizeAndCaseStudy"> 2020.06, IoTDB 性能优化及案例分享. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/IoTDBOptimizeAndCaseStudy" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "IoTDBQuickStart"> 2020.05, IoTDB 基本使用. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/IoTDBQuickStart" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "IoTDBOps"> 2020.05, IoTDB 部署运维及常见问题. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/IoTDBOps" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* <span id = "meetup2019-pulsar1"> 2020.01, 北京Meetup 2019. 基于Apache IoTDB的时序数据开源解决方案. Reporter: Jialin Qiao. </span>

<iframe src="https://www.slidestalk.com/IoTDB/IoTDB_meetup_2020_01" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

<iframe src="//player.bilibili.com/player.html?aid=83462398&bvid=BV1sJ411J783&cid=142782989&page=5"   width="640" height="480" scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2019-pulsar2"> 2020.01, 北京Meetup 2019. Apache IoTDB的前世今生与技术细节. Reporter: Xiangdong Huang. </span>

<iframe src="https://www.slidestalk.com/IoTDB/202001Meetup2019ApacheIoTDBReporterXiangdongHuang24508" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe> 

<iframe src="//player.bilibili.com/player.html?aid=83462398&bvid=BV1sJ411J783&cid=142782348&page=3"   width="640" height="480"  scrolling="no" border="0" frameborder="no" framespacing="0" allowfullscreen="true"> </iframe>

* <span id = "meetup2019-dalian"> 2019.12, 大连Meetup 2019. Apache IoTDB: 工业互联网时序数据库. Reporter: Xiangdong Huang. </span>

<iframe src="https://www.slidestalk.com/IoTDB/201912Meetup2019ApacheIoTDBReporterXiangdongHuang71222" width="562.5" height="492.5" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe>

* [IoTDB v0.8.0 Query Process Implementation], Reporter: Lei Rui
